##  Creating and Managing Workspace Views
You can create and manage workspace views in the Workspace Views section of the administration area.
![Workspace Views in the Administration Area](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2755330a7a441014a788a8946ac52dda_LowRes.png)
Workspace Views in the Administration Area
